@@ -1891,7 +1891,7 @@ class SecretManagerServiceAsyncClient:
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
-            "google-cloud-secretmanager",
+            "google-cloud-secret-manager",
         ).version,
     )
 except pkg_resources.DistributionNotFound:
